# Getting Started with React Admin Dashboard for ApiLogicServer

React based Web Admin Dashboard for [APILogicServer](https://github.com/valhuber/ApiLogicServer). 

[View live demo!](https://apilogicserver.askteam.how/) 
(username is admin and password is p)

## Installation

Before you install this react dashboard for APILogicServer, you need to have npm, node and yarn installed on your local machine. 

Use this website to install npm, node and yarn - [https://nodejs.org/en/download/](https://nodejs.org/en/download/).

### `yarn install`
This will install all the dependencies listed within package.json.

### `yarn start`
Runs the app in the development mode.\
Open [http://localhost:3000](http://localhost:3000) to view it in the browser.

The page will reload if you make edits.\
You will also see any lint errors in the console.

### `yarn build`

Builds the app for production to the `build` folder.\

## How to Get Support

Contact the developer meera.datey@gmail.com

